@@ -3,7 +3,7 @@ package Apache2::ASP::UploadHandler;
 
 use strict;
 use base 'Apache2::ASP::Handler';
-our $LastUpdate;
+our %LastUpdate;
 
 use vars qw(
   %modes
@@ -14,9 +14,11 @@ sub upload_start
 {
   my ($s, $asp, $Upload) = @_;
   
+  my ($id) = $ENV{QUERY_STRING} =~ m/upload_id\=(\w+)/;
+  
   # Store the upload information in the Session for external retrieval:
-  $LastUpdate = time();
-  $asp->session->{$_} = $Upload->{$_}
+  $LastUpdate{$id} = time();
+  $asp->session->{"$id\_$_"} = $Upload->{$_}
     foreach keys(%$Upload);
   $asp->session->save;
 }# end upload_start()
@@ -27,10 +29,13 @@ sub upload_end
 {
   my ($s, $asp, $Upload) = @_;
   
+  my ($id) = $ENV{QUERY_STRING} =~ m/upload_id\=(\w+)/;
+  
   # Clear out the upload data from the Session:
-  delete($asp->session->{$_})
+  delete($asp->session->{"$id\_$_"})
     foreach keys(%$Upload);
   $asp->session->save;
+  delete($LastUpdate{$id});
 }# end upload_end()
 
 
@@ -39,17 +44,19 @@ sub upload_hook
 {
   my ($s, $asp, $Upload) = @_;
   
+  my ($id) = $ENV{QUERY_STRING} =~ m/upload_id\=(\w+)/;
+  
   # Since this method may be called several times per second, we only
   # want to save the Session state once per second:
-  my $Diff = time() - $LastUpdate;
+  my $Diff = time() - $LastUpdate{$id};
   if( $Diff >= 1 )
   {
     # Store everything in the session except for the data 
     # (since that could be too large to serialize quickly):
-    $asp->session->{$_} = $Upload->{$_}
+    $asp->session->{"$id\_$_"} = $Upload->{$_}
       foreach grep { $_ ne 'data' } keys(%$Upload);
     $asp->session->save;
-    $LastUpdate = time();
+    $LastUpdate{$id} = time();
   }# end if()
 }# end upload_hook()
 
@@ -103,7 +110,7 @@ Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Apache2-ASP> to submit bug rep
 
 =head1 HOMEPAGE
 
-Please visit the Apache2::ASP homepage at L<http://apache2-asp.no-ip.org/> to see examples
+Please visit the Apache2::ASP homepage at L<http://www.devstack.com/> to see examples
 of Apache2::ASP in action.
 
 =head1 AUTHOR
