@@ -67,7 +67,8 @@ sub hook
     
     # End the upload if we are done:
     $s->{asp}->r->push_handlers(PerlCleanupHandler => sub {
-      delete($s->{asp}->session->{$_})
+      my $id = $s->{asp}->request->Form->{upload_id};
+      delete($s->{asp}->session->{"$id\_$_"})
         foreach keys(%$Upload);
       $s->{asp}->session->save;
     });
@@ -75,6 +76,7 @@ sub hook
   
   if( $length_received <= 0 )
   {
+    $s->{handler_class}->init_asp_objects( $s->{asp} );
     $s->{handler_class}->upload_end( $s->{asp}, $Upload );
   }# end if()
   
